changeset 60:dbb576385da5

Adding layer rotation (next/prev) support - Includes symbolic names
author Jacob Alexander <haata@kiibohd.com>
date Mon, 28 Sep 2015 20:00:22 -0700
parents 7840a116a632
children 4a11bc59c013
files kll_lib/hid_dict.py layouts/lcdFuncMap.kll layouts/stdFuncMap.kll
diffstat 3 files changed, 15 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/layouts/lcdFuncMap.kll	Sun Sep 20 14:45:42 2015 -0700
+++ b/layouts/lcdFuncMap.kll	Mon Sep 28 20:00:22 2015 -0700
@@ -4,7 +4,7 @@
 KLL = 0.3c;
 
 # Modified Date
-Date = 2015-09-20;
+Date = 2015-09-24;
 
 # Maps each Function key incrementally to each layer
 # Unused layers and functions are ignored
@@ -60,6 +60,10 @@
 U"Latch15" : layerLatch( 15 ) + LCDLayerDisplay();
 U"Latch16" : layerLatch( 16 ) + LCDLayerDisplay();
 
+# Layer rotation
+U"Next Layer" : layerRotate( 0 ) + LCDLayerDisplay(); # 0 is Next
+U"Prev Layer" : layerRotate( 1 ) + LCDLayerDisplay(); # 1 is Previous
+
 
 # Colours assigned to each of the LCD numbers
 # The "top of stack" layer is the colour used
--- a/layouts/stdFuncMap.kll	Sun Sep 20 14:45:42 2015 -0700
+++ b/layouts/stdFuncMap.kll	Mon Sep 28 20:00:22 2015 -0700
@@ -4,7 +4,7 @@
 KLL = 0.3;
 
 # Modified Date
-Date = 2015-09-20;
+Date = 2015-09-24;
 
 # Maps each Function key incrementally to each layer
 # Unused layers and functions are ignored
@@ -60,3 +60,7 @@
 U"Latch15" : layerLatch( 15 );
 U"Latch16" : layerLatch( 16 );
 
+# Layer rotation
+U"Next Layer" : layerRotate( 0 ); # 0 is Next
+U"Prev Layer" : layerRotate( 1 ); # 1 is Previous
+
--- a/kll_lib/hid_dict.py	Sun Sep 20 14:45:42 2015 -0700
+++ b/kll_lib/hid_dict.py	Mon Sep 28 20:00:22 2015 -0700
@@ -262,7 +262,7 @@
 	( ('USB', 0xFD), 'KEY_FUN14' ),
 	( ('USB', 0xFE), 'KEY_FUN15' ),
 	( ('USB', 0xFF), 'KEY_FUN16' ),
 # ('USB', 0x100) to ('USB', 0x11F) for function key placeholders, not valid usb codes (must use a translation .kll file before firmware compilation)
 	( ('USB', 0x100), 'KEY_LCK1' ),
 	( ('USB', 0x101), 'KEY_LCK2' ),
 	( ('USB', 0x102), 'KEY_LCK3' ),
@@ -295,6 +295,8 @@
 	( ('USB', 0x11D), 'KEY_LAT14' ),
 	( ('USB', 0x11E), 'KEY_LAT15' ),
 	( ('USB', 0x11F), 'KEY_LAT16' ),
+	( ('USB', 0x120), 'KEY_NEXT_LAYER' ),
+	( ('USB', 0x121), 'KEY_PREV_LAYER' ),
 
 	# USB HID Consumer Control Codes
 # List of Consumer Codes - USB HID 1.12v2
@@ -1057,6 +1059,8 @@
 	( 'LAT14', ('USB', 0x11D) ), ( 'LATCH14', ('USB', 0x11D) ),
 	( 'LAT15', ('USB', 0x11E) ), ( 'LATCH15', ('USB', 0x11E) ),
 	( 'LAT16', ('USB', 0x11F) ), ( 'LATCH16', ('USB', 0x11F) ),
+	( 'NLAYER', ('USB', 0x120) ), ( 'NEXT LAYER', ('USB', 0x120) ),
+	( 'PLAYER', ('USB', 0x121) ), ( 'PREV LAYER', ('USB', 0x121) ),
 ])
 
 
@@ -262,7 +262,7 @@
 	( ('USB', 0xFE), 'KEY_FUN15' ),
 	( ('USB', 0xFF), 'KEY_FUN16' ),
-# ('USB', 0x100) to ('USB', 0x11F) for function key placeholders, not valid usb codes (must use a translation .kll file before firmware compilation)
+# ('USB', 0x100) to ('USB', 0x121) for function key placeholders, not valid usb codes (must use a translation .kll file before firmware compilation)
 	( ('USB', 0x100), 'KEY_LCK1' ),
 	( ('USB', 0x101), 'KEY_LCK2' ),